SlideAnimator class
Inheritance
Mixed-in types
Implementers
Properties
absoluteRatio
→ double
no setter
hashCode
→ int
The hash code for this object.
no setter inherited
hasListeners
→ bool
Whether any listeners are currently registered.
no setter inherited
ratio
→ double
represents the current sliding ratio relative to the size of the SlidePanel
if ratio > 0 indicates we are sliding to see the pre actions
if ratio < 0 indicates we are sliding to see the post actions
if ratio == 0 indicates we are not sliding, all actions are hidden, only the main child is visible
no setter
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
slidePercent
→ Animation <double >
no setter
Methods
addListener (VoidCallback listener )
→ void
Register a closure to be called when the object changes.
inherited
createTicker (TickerCallback onTick )
→ Ticker
Creates a ticker with the given callback.
override
dispose ()
→ void
Discards any resources used by the object.
override
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners ()
→ void
Call all the registered listeners.
inherited
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
toString ()
→ String
A string representation of this object.
inherited
flutter_slidable_panel 1.1.4